==> haskell-streaming-commons-0.2.2.1-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.1
visibility:           public
id:                   streaming-commons-0.2.2.1-AULsTq5CbUZCBazOM3cQIR
key:                  streaming-commons-0.2.2.1-AULsTq5CbUZCBazOM3cQIR
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  9f1dd6cdda4bb9f3bb6f2bce0b1d5022
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

hidden-modules:
    Data.Text.Internal.Unsafe.Char Data.Text.Internal.Unsafe.Shift
    Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Encoding.Utf16
    Data.Text.Internal.Encoding.Utf32

import-dirs:          /usr/lib/ghc-9.0.1/site-local/streaming-commons-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/streaming-commons-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/streaming-commons-0.2.2.1
hs-libraries:         HSstreaming-commons-0.2.2.1-AULsTq5CbUZCBazOM3cQIR
depends:
    array-0.5.4.0 async-2.2.3-Hbf8iw1TAQkCo5mSzdU6hX base-4.15.0.0
    bytestring-0.10.12.1 directory-1.3.6.1
    network-3.1.2.2-HGbVE4boZ66LTdBzqgSQTe process-1.6.11.0
    random-1.2.1-LetExsLOa3nDkhT0M1R6w stm-2.5.0.0 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.2.3-InpZ1222O6ECIxgu3OX6sU

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.2.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.1
visibility:           public
id:                   streaming-commons-0.2.2.1-7nqmyj2WLcaJXLarflT37c
key:                  streaming-commons-0.2.2.1-7nqmyj2WLcaJXLarflT37c
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  23d0a2d13b03cea370a81d4e79dce4db
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

hidden-modules:
    Data.Text.Internal.Unsafe.Char Data.Text.Internal.Unsafe.Shift
    Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Encoding.Utf16
    Data.Text.Internal.Encoding.Utf32

import-dirs:          /usr/lib/ghc-9.0.1/site-local/streaming-commons-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/streaming-commons-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/streaming-commons-0.2.2.1
hs-libraries:         HSstreaming-commons-0.2.2.1-7nqmyj2WLcaJXLarflT37c
depends:
    array-0.5.4.0 async-2.2.3-JMLEcS5xCFd7RA7gdjgDSR base-4.15.0.0
    bytestring-0.10.12.1 directory-1.3.6.1
    network-3.1.2.2-CXlDaZn7SUD6Bf6tae6Y5g process-1.6.11.0
    random-1.2.1-CJdGQfuMFBr50G0gL4deb3 stm-2.5.0.0 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.2.3-9KdQRdAK0al9cH28ga1ICC

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
